import 'dart:convert';

import 'package:cloud_firestore/cloud_firestore.dart';
import 'package:firebase_auth/firebase_auth.dart';
import 'package:flutter/material.dart';

// Puma Firestore.
class PumaFirestore {
  static synchronizeDocuments(
    String collection, {
    Function(List<String>)? onCompleted,
    String uidField = "ownerID",
  }) {
    if (FirebaseAuth.instance.currentUser == null) return;

    User user = FirebaseAuth.instance.currentUser!;
    bool foundDocuments = false;

    CollectionReference col = FirebaseFirestore.instance.collection(collection);

    var snapshot = col.where(uidField, isEqualTo: user.uid).get();

    snapshot.catchError((e) {
      debugPrint("Something went wrong");
      debugPrint(e.toString());
    });

    snapshot.then((value) {
      List<String> documents = [];
      foundDocuments = true;

      for (var doc in value.docs) {
        documents.add(jsonEncode(doc.data()));
      }

      if (onCompleted != null) {
        onCompleted(documents);
      }
    });

    snapshot.whenComplete(() {
      if (!foundDocuments) {
        debugPrint("No documents found in Firestore");
        if (onCompleted != null) {
          onCompleted([]);
        }
      }
    });
  }

  static uploadDocument(String collection, String uuid, String obj) {
    if (FirebaseAuth.instance.currentUser == null) return;

    CollectionReference col = FirebaseFirestore.instance.collection(collection);

    col.doc(uuid).set(json.decode(obj));
  }

  static deleteDocument(String collection, String uuid) {
    if (FirebaseAuth.instance.currentUser == null) return;

    CollectionReference col = FirebaseFirestore.instance.collection(collection);

    col.doc(uuid).delete();
  }

  static listenToDocumentChanges(
    String collection, {
    Function(List<String>)? onChanged,
    Function(String)? onAdded,
    Function(String)? onModified,
    Function(String)? onRemoved,
    String uidField = "ownerID",
  }) {
    if (FirebaseAuth.instance.currentUser == null) return;

    User user = FirebaseAuth.instance.currentUser!;

    var query = FirebaseFirestore.instance
        .collection(collection)
        .where(uidField, isEqualTo: user.uid);

    // query = query.where('sharedTo', arrayContains: user.uid);

    Stream stream = query.snapshots();

    stream.listen((querySnapshot) {
      List<String> documents = [];

      querySnapshot.docs.forEach((doc) {
        documents.add(jsonEncode(doc.data()));
      });

      if (onChanged != null) {
        onChanged(documents);
      }

      querySnapshot.docChanges.forEach((res) {
        if (res.type == DocumentChangeType.added) {
          debugPrint("Added");
          if (onAdded != null) onAdded(jsonEncode(res.doc.data()));
        } else if (res.type == DocumentChangeType.modified) {
          debugPrint("modified");
          if (onModified != null) onModified(jsonEncode(res.doc.data()));
        } else if (res.type == DocumentChangeType.removed) {
          debugPrint("removed");
          if (onRemoved != null) onRemoved(jsonEncode(res.doc.data()));
        }
      });
    });
  }
}
