import 'package:flutter/material.dart';
import 'package:puma_firebase/entities/fireuser.dart';
import 'package:puma_firebase/firebase.dart';

class GoogleSignInButton extends StatefulWidget {
  final Function(bool, PumaFireUser?) onCompleted;
  final Function(dynamic) onError;
  final String text;

  const GoogleSignInButton({
    Key? key,
    required this.onCompleted,
    required this.onError,
    this.text = "Sign in with Google",
  }) : super(key: key);

  @override
  GoogleSignInButtonState createState() => GoogleSignInButtonState();
}

class GoogleSignInButtonState extends State<GoogleSignInButton> {
  @override
  Widget build(BuildContext context) {
    return Container(
      decoration: BoxDecoration(
        border: Border.all(
          color: Colors.black,
        ),
        borderRadius: const BorderRadius.all(
          Radius.circular(20),
        ),
      ),
      child: OutlinedButton(
        style: ButtonStyle(
          backgroundColor: MaterialStateProperty.all(
            Colors.white,
          ),
          shape: MaterialStateProperty.all(
            RoundedRectangleBorder(
              borderRadius: BorderRadius.circular(40),
            ),
          ),
        ),
        onPressed: () {
          PumaFirebase.signInWithGoogle(
            onCompleted: widget.onCompleted,
            onError: widget.onError,
          );
        },
        child: Padding(
          padding: const EdgeInsets.fromLTRB(0, 10, 0, 10),
          child: Row(
            mainAxisSize: MainAxisSize.max,
            mainAxisAlignment: MainAxisAlignment.center,
            children: [
              googleImage(),
              buttonText(),
            ],
          ),
        ),
      ),
    );
  }

  Widget googleImage() {
    return const Image(
      image: AssetImage("packages/puma_firebase/assets/google_logo.png"),
      height: 25.0,
    );
  }

  Widget buttonText() {
    return Padding(
      padding: const EdgeInsets.only(left: 10),
      child: Text(
        widget.text,
        style: const TextStyle(
          fontSize: 20,
          color: Colors.black54,
          fontWeight: FontWeight.w600,
        ),
      ),
    );
  }
}
