import 'package:flutter/material.dart';
import 'package:puma_firebase/entities/fireuser.dart';
import 'package:puma_firebase/ui/molecules/apple_signin_button.dart';
import 'package:puma_firebase/ui/molecules/google_signin_button.dart';

class SigninButtons extends StatefulWidget {
  final bool googleEnabled;
  final bool appleEnabled;
  final Function(bool, PumaFireUser?) onComplete;
  final Function(dynamic) onError;

  const SigninButtons({
    Key? key,
    required this.onComplete,
    required this.onError,
    this.googleEnabled = true,
    this.appleEnabled = true,
  }) : super(key: key);

  @override
  SigninButtonsState createState() => SigninButtonsState();
}

class SigninButtonsState extends State<SigninButtons> {
  Widget getLoginButtons() {
    return Column(
      crossAxisAlignment: CrossAxisAlignment.stretch,
      children: [
        // Signin With Apple
        if (widget.appleEnabled)
          AppleSignInButton(
            onCompleted: widget.onComplete,
            onError: widget.onError,
          ),
        // Signin With Google
        if (widget.googleEnabled)
          Padding(
            padding: const EdgeInsets.only(top: 16.0),
            child: GoogleSignInButton(
              onCompleted: widget.onComplete,
              onError: widget.onError,
            ),
          ),
      ],
    );
  }

  @override
  Widget build(BuildContext context) {
    return getLoginButtons();
  }
}
